@@ -13,8 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
-
+from oslo_utils import uuidutils
 from zaqarclient.common import decorators
 from zaqarclient.queues.v1 import core
 from zaqarclient.queues.v1 import flavor
@@ -30,28 +29,26 @@ class Client(object):
     """Client base class
 
     :param url: Zaqar's instance base url.
-    :type url: `six.text_type`
+    :type url: str
     :param version: API Version pointing to.
     :type version: `int`
-    :param options: Extra options:
-        - client_uuid: Custom client uuid. A new one
-        will be generated, if not passed.
-        - auth_opts: Authentication options:
-            - backend
-            - options
-    :type options: `dict`
+    :param conf: CONF object.
+    :type conf: `oslo_config.cfg.CONF`
+    :param session: keystone session. But it's just place holder, we wont'
+        support it in v1.
     """
 
     queues_module = queues
 
-    def __init__(self, url=None, version=1, conf=None):
+    def __init__(self, url=None, version=1, conf=None, session=None):
         self.conf = conf or {}
 
         self.api_url = url
         self.api_version = version
         self.auth_opts = self.conf.get('auth_opts', {})
         self.client_uuid = self.conf.get('client_uuid',
-                                         uuid.uuid4().hex)
+                                         uuidutils.generate_uuid(dashed=False))
+        self.session = session
 
     def _get_transport(self, request):
         """Gets a transport and caches its instance
@@ -66,14 +63,15 @@ class Client(object):
         :type request: :class:`zaqarclient.transport.request.Request`
         """
 
-        trans = transport.get_transport_for(request,
-                                            options=self.conf)
-        return (trans or self.transport)
+        return transport.get_transport_for(request,
+                                           version=self.api_version,
+                                           options=self.conf)
 
     def _request_and_transport(self):
         req = request.prepare_request(self.auth_opts,
                                       endpoint=self.api_url,
-                                      api=self.api_version)
+                                      api=self.api_version,
+                                      session=self.session)
 
         req.headers['Client-ID'] = self.client_uuid
 
@@ -86,13 +84,13 @@ class Client(object):
         :rtype: :class:`zaqarclient.transport.base.Transport`
         """
         return transport.get_transport_for(self.api_url,
-                                           self.api_version)
+                                           version=self.api_version)
 
     def queue(self, ref, **kwargs):
         """Returns a queue instance
 
         :param ref: Queue's reference id.
-        :type ref: `six.text_type`
+        :type ref: str
 
         :returns: A queue instance
         :rtype: `queues.Queue`
@@ -122,7 +120,7 @@ class Client(object):
         gotten from `links` sections in responses like queues' lists.
 
         :params ref: The reference path.
-        :type ref: `six.text_type`
+        :type ref: str
         """
         req, trans = self._request_and_transport()
         req.ref = ref
@@ -134,7 +132,7 @@ class Client(object):
         """Returns a pool instance
 
         :param ref: Pool's reference name.
-        :type ref: `six.text_type`
+        :type ref: str
 
         :returns: A pool instance
         :rtype: `pool.Pool`
@@ -145,7 +143,7 @@ class Client(object):
         """Gets a list of pools from the server
 
         :param params: Filters to use for getting pools
-        :type params: **kwargs dict.
+        :type params: dict.
 
         :returns: A list of pools
         :rtype: `list`
@@ -164,7 +162,7 @@ class Client(object):
         """Returns a flavor instance
 
         :param ref: Flavor's reference name.
-        :type ref: `six.text_type`
+        :type ref: str
 
         :returns: A flavor instance
         :rtype: `flavor.Flavor`
@@ -176,7 +174,7 @@ class Client(object):
         """Gets a list of flavors from the server
 
         :param params: Filters to use for getting flavors
-        :type params: **kwargs dict.
+        :type params: dict.
 
         :returns: A list of flavors
         :rtype: `list`
